--- apps/app_queue.c.orig	2009-11-10 23:00:02.000000000 -0800
+++ apps/app_queue.c	2009-11-12 23:08:59.000000000 -0800
@@ -5150,12 +5150,24 @@
 		} else if (!strcasecmp(option, "free")) {
 			mem_iter = ao2_iterator_init(q->members, 0);
 			while ((m = ao2_iterator_next(&mem_iter))) {
-				/* Count the agents who are logged in and presently answering calls */
+				/* Count the agents who are logged in and maybe can take calls, unless presently wrapping up */
 				if ((m->status == AST_DEVICE_NOT_INUSE) && (!m->paused)) {
 					count++;
 				}
 				ao2_ref(m, -1);
 			}
+		} else if (!strcasecmp(option, "ready")) {
+			time_t now;
+			time(&now);
+			mem_iter = ao2_iterator_init(q->members, 0);
+			while ((m = ao2_iterator_next(&mem_iter))) {
+				/* Count the agents who are logged in, not paused and not wrapping up */
+				if ((m->status == AST_DEVICE_NOT_INUSE) && (!m->paused) &&
+						!(m->lastcall && q->wrapuptime && (now - q->wrapuptime < m->lastcall))) {
+					count++;
+				}
+				ao2_ref(m, -1);
+			}
 		} else /* must be "count" */
 			count = q->membercount;
 		ao2_unlock(q);
@@ -5389,8 +5401,11 @@
 "Returns the number of members currently associated with the specified queue.\n"
 "One of three options may be passed to determine the count returned:\n"
 	"\"logged\" - Returns the number of logged-in members for the specified queue\n"
-	"\"free\" - Returns the number of logged-in members for the specified queue available to take a call\n"
-	"\"count\" - Returns the total number of members for the specified queue\n",
+	"\"free\"   - Returns the number of logged-in members for the specified queue that\n"
+        "           either can take calls or are currently wrapping up after a previous call\n"
+	"\"ready\"  - Returns the number of logged-in members for the specified queue that\n"
+        "           are immediately available to answer a call\n"
+	"\"count\"  - Returns the total number of members for the specified queue\n",
 	.read = queue_function_qac,
 };
 
